@@ -47,7 +47,7 @@
 #include "gzfileio.h"
 #include "list.h"
 
-USING_NAMESPACE_STD
+USING_NAMESPACE_STD;
 
 /*************************************************************************
 	Directory class.
