@@ -35,6 +35,6 @@ void	SetScanTime(time_t t);
 void	LoadDirFile(int quiet);
 void	WriteDirFile();
 
-int	operator < (DirectoryEntry &a, DirectoryEntry &b);
+int	operator < (const DirectoryEntry &a, const DirectoryEntry &b);
 
 #endif	/* __K_DIRTREE_H */
