@@ -146,12 +146,12 @@ int	EditBox::ProcessKey(int key)
 			break;
 		case KEY_LEFT:
 			if(curPos > 0)
-				curPos = GetWStringWidthFirstCharAtPos(buffer, curPos-1);
+				curPos = GetWStringWidthLastCharAtPos(buffer, curPos-1);
 			wmove(win, yPos, xPos+curPos);
 			break;
 		case KEY_RIGHT:
 			if(curPos < GetWStringWidth(buffer))
-				curPos = GetWStringWidthFirstCharAtPos(buffer, curPos+1);
+				curPos = GetWStringWidthLastCharAtPos(buffer, curPos+1);
 			wmove(win, yPos, xPos+curPos);
 			break;
 		case KEY_IC:
@@ -160,9 +160,8 @@ int	EditBox::ProcessKey(int key)
 		case KEY_DC:
 			if(curPos < GetWStringWidth(buffer) && buffer.size()) {
 
-				size_t	del_pos = GetWStringWidthFirstCharAtPos(buffer, curPos+1);
+				size_t	del_pos = GetWStringLastCharAtPos(buffer, curPos+1);
 				buffer.erase(del_pos-1, 1);
-				curPos = GetWStringWidth(buffer, del_pos-1);
 
 				Show();
 				ret = 1;
@@ -176,7 +175,7 @@ int	EditBox::ProcessKey(int key)
 		case KEY_BACKSPACE:
 			if(curPos > 0) {
 
-				size_t	del_pos = GetWStringWidthFirstCharAtPos(buffer, curPos);
+				size_t	del_pos = GetWStringLastCharAtPos(buffer, curPos);
 				buffer.erase(del_pos-1, 1);
 				curPos = GetWStringWidth(buffer, del_pos-1);
 
@@ -204,7 +203,7 @@ int	EditBox::ProcessKey(int key)
 #endif
 
 								// Get this character position
-						size_t	ins_pos = GetWStringWidthFirstCharAtPos(buffer, curPos);
+						size_t	ins_pos = GetWStringLastCharAtPos(buffer, curPos);
 						buffer.insert(ins_pos, 1, unicode_key);
 						curPos = GetWStringWidth(buffer, ins_pos+1);
 
@@ -228,7 +227,7 @@ int	EditBox::ProcessKey(int key)
 					size_t	new_pos = curPos;
 					size_t	del_pos;
 					do {
-						del_pos = GetWStringWidthFirstCharAtPos(buffer, curPos+1);
+						del_pos = GetWStringLastCharAtPos(buffer, curPos+1);
 						buffer.erase(del_pos-1, 1);
 						new_pos = GetWStringWidth(buffer, del_pos-1);
 					} while (new_pos > curPos);
