@@ -73,10 +73,7 @@ void	HandleChdirError(ScanLog &scan_log, const string &dir, int e)
 {
 	if (e == EACCES)
 		return;
-	if (e < sys_nerr)	// FIXME: Need gettext for sys_errlist ?
-		scan_log.PrintChdirError(dir, sys_errlist[e]);
-	else
-		scan_log.PrintChdirError(dir, _("unknown error"));
+	scan_log.PrintChdirError(dir, strerror(e));
 }
 
 /*************************************************************************
