@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-USING_NAMESPACE_STD
+USING_NAMESPACE_STD;
 
 // nest = 0, no nested " ' `
 // nest = 1, nested " ' `
